from setuptools import setup

setup(name='gb78_distributions_7',
      version='1.0',
      description='Gaussian distributions',
      packages=['gb78_distributions7'],
      author = 'Daniel Pedraza',
      author_email = 'dpedrazatrivino2@gmail.com',
      zip_safe=False)